#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without test
%define psuffix -test
# Tests known to fail on 32 bit due to fp precision
ExcludeArch:    %{ix86}
%else
%bcond_with test
%define psuffix %{nil}
%endif

%define pname lscsoft-glue
# Support dropped for python2 by upstream
%define skip_python2 1

%define modname glue
Name:           lscsoft-glue%{psuffix}
Version:        4.0.0
Release:        1.3
Summary:        Grid LSC User Environment
License:        GPL-2.0-only
URL:            http://software.ligo.org/lscsoft
Source:         https://files.pythonhosted.org/packages/source/l/lscsoft-glue/%{pname}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ligo-segments
Requires:       python-numpy
Requires:       python-pyOpenSSL
Requires:       python-six
Provides:       lscsoft-glue-data = %{version}
Obsoletes:      lscsoft-glue-data < %{version}
Provides:       python-glue = %{version}-%{release}
Obsoletes:      python-glue < %{version}-%{release}
BuildArch:      noarch
%define oldpython python
Provides:       %{oldpython}-glue = %{version}-%{release}
Obsoletes:      %{oldpython}-glue < %{version}-%{release}
%if %{with test}
BuildRequires:  %{python_module lal}
BuildRequires:  %{python_module ligo-segments}
BuildRequires:  %{python_module lscsoft-glue = %{version}}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
%endif
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
Glue is a collection of utilities for running data analysis pipelines
for online and offline analysis as well as accessing various grid
utilities.  It also provides the infrastructure for the segment
database.

%package -n %{pname}-data
Summary:        Collection of data files for use by %{name}

%description -n %{pname}-data
Glue is a collection of utilities for running data analysis pipelines
for online and offline analysis as well as accessing various grid
utilities.  It also provides the infrastructure for the segment
database.

This package provides a common set of data files for %{name}.

%prep
%autosetup -p1 -n %{pname}-%{version}
# Taken from bundled specfile template
%if 0%{?suse_version} < 1650
cat > setup.cfg <<EOF
[metadata]
name = %{pname}
version = %{version}
description = %{summary}
license = %{license}
license_files = LICENSE
url = %{url}
[options]
packages = find:
python_requires = >=3.6
install_requires =
	ligo-segments
	pyOpenSSL
	six
EOF
%endif

%build
%if ! %{with test}
%pyproject_wheel
%endif

%install
%if ! %{with test}
%pyproject_install

# SECTION Remove non-library config/php files
rm -fr %{buildroot}%{_prefix}%{_sysconfdir}
rm -fr %{buildroot}%{_prefix}%{_localstatedir}
# /SECTION

%python_expand %fdupes -s %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# test_ldbd.py requires network; disable
%pytest -k 'not test_ldbd'
%endif

%if ! %{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/glue/
%{python_sitelib}/lscsoft_glue-%{version}*-info
%endif

%changelog
* Tue Aug 13 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.0:
  * lots of library content, and all scripts, has been removed
  * removed lscsoft-glue-utils package
  * use pybuild-plugin-pyproject for building
- Drop lscsoft-glue-data package: no longer applicable.
- Make package noarch.
- Switch to %%pyproject_* based builds; add BuildRequires:
  python-pip and python-wheel.
- New Requires: python-six and python-pyOpenSSL; drop no longer
  needed python-pyRXP.
- Add setup.cfg snippet to allow building for openSUSE Leap 15.x.
* Mon Jan 15 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update for version 3.0.2:
  * Remove P2/P3 transitional packages
  * Testing updates.
- Drop condtionals referring to python 3.6.
* Tue Feb  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.1:
  * Removed support for Python 2.
  * Numerous fixes for Python 3 support.
  * Removed numerous unused (and usually broken) files,
    functions/methods, etc.
  * Lots of cleanup of code base.
  * Added new unit tests.
  * Improved setup and packaging code.
  * Added deprecation messages for code that will be removed in a
    future version.
- Drop patches incorporated upstream:
  * lscsoft-glue-python-3.10-fixes.patch.
  * lscsoft-glue-disable-doctest.patch.
- Use pytest to run tests; drop a network dependent test.
- Add BuildRequires: python-pyRXP for test flavor; needed for one
  of the new tests.
- Split out new package, lscsoft-glue-data, with data files
  needed by all lscsoft-glue binaries; required by all
  python-lscsoft-glue flavors.
- Redefine ligocommands macro to refer to updated binaries
  installed.
* Fri Jan 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add lscsoft-glue-python-3.10-fixes.patch: Fix python3.10
  compatibility; patch taken from upstream merge request
  [https://git.ligo.org/lscsoft/glue/-/merge_requests/83].
- Add lscsoft-glue-disable-doctest.patch: Disable some doctests
  not yet ready for python 3.10
- Add Requires(post) and Requires(postun) on update-alternatives.
* Mon Feb 15 2021 Ben Greiner <code@bnavigator.de>
- Revert the Obsoletes/Provides removal of python-glue.
* Fri Feb 12 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build. Due to NEP 29, numpy, matplotlib and co.
  do not have a python36 flavored package in TW
* Thu Jan 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Fix Obsoletes/Provides for python-glue to fix problems with
  python multi-versioning.
* Mon Jan 18 2021 Benjamin Greiner <code@bnavigator.de>
- Install commands with update-alternatives to avoid conflicts with
  multiple python3 flavors
- Test in multibuild to avoid dependency cycle with python-lal
  (runtime dep)
* Sat Oct 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.0:
  * Test release with deprecations.
- Run tests as part of %%check section (64-bit and python3 only);
  entails additional BuildRequires: python-ligo-segments,
  python-matplotlib, and python-numpy.
- Add python-numpy and python-ligo-segments to Requires as they
  are needed for any meaningful usage of the module.
* Thu Apr 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package (source name change from python-glue).
